@@ -2,35 +2,18 @@ use 5.006;
 use strict;
 use warnings;
 package Test::MinimumVersion;
+BEGIN {
+  $Test::MinimumVersion::VERSION = '0.101050';
+}
 use base 'Exporter';
+# ABSTRACT: does your code require newer perl than you think?
 
-=head1 NAME
-
-Test::MinimumVersion - does your code require newer perl than you think?
-
-=head1 VERSION
-
-version 0.012
-
-=cut
-
-our $VERSION = '0.012';
-
-=head1 SYNOPSIS
-
-Example F<minimum-perl.t>:
-
-  #!perl
-  use Test::MinimumVersion;
-  all_minimum_version_ok('5.008');
-
-=cut
 
 use File::Find::Rule;
 use File::Find::Rule::Perl;
-use Perl::MinimumVersion 1.20;
-use YAML::Tiny;
-use version;
+use Perl::MinimumVersion 1.20; # accuracy
+use YAML::Tiny 1.40; # bug fixes
+use version 0.70;
 
 use Test::Builder;
 @Test::MinimumVersion::EXPORT = qw(
@@ -58,15 +41,6 @@ sub _objectify_version {
            : version->new($version);
 }
 
-=head2 minimum_version_ok
-
-  minimum_version_ok($file, $version);
-
-This test passes if the given file does not seem to require any version of perl
-newer than C<$version>, which may be given as a version string or a version
-object.
-
-=cut
 
 sub minimum_version_ok {
   my ($file, $version) = @_;
@@ -77,7 +51,7 @@ sub minimum_version_ok {
 
   my $pmv = Perl::MinimumVersion->new($file);
 
-  my $explicit_minimum = $pmv->minimum_explicit_version;
+  my $explicit_minimum = $pmv->minimum_explicit_version || 0;
   my $minimum = $pmv->minimum_syntax_version($explicit_minimum);
 
   my $is_syntax = 1
@@ -106,24 +80,6 @@ sub minimum_version_ok {
   }
 }
 
-=head2 all_minimum_version_ok
-
-  all_minimum_version_ok($version, \%arg);
-
-Given either a version string or a L<version> object, this routine produces a
-test plan (if there is no plan) and tests each relevant file with
-C<minimum_version_ok>.
-
-Relevant files are found by L<File::Find::Rule::Perl>.
-
-C<\%arg> is optional.  Valid arguments are:
-
-  paths   - in what paths to look for files; defaults to (t, lib, xt/smoke,
-            and any .pm or .PL files in the current working directory)
-            if it contains files, they will be checked
-  no_plan - do not plan the tests about to be run
-
-=cut
 
 sub all_minimum_version_ok {
   my ($version, $arg) = @_;
@@ -150,16 +106,6 @@ sub all_minimum_version_ok {
   minimum_version_ok($_, $version) for @perl_files;
 }
 
-=head2 all_minimum_version_from_metayml_ok
-
-  all_minimum_version_from_metayml_ok(\%arg);
-
-This routine checks F<META.yml> for an entry in F<requires> for F<perl>.  If no
-META.yml file or no perl version is found, all tests are skipped.  If a version
-is found, the test proceeds as if C<all_minimum_version_ok> had been called
-with that version.
-
-=cut
 
 sub all_minimum_version_from_metayml_ok {
   my ($arg) = @_;
@@ -178,21 +124,73 @@ sub all_minimum_version_from_metayml_ok {
   all_minimum_version_ok($version, $arg);
 }
 
-=head1 TODO
+1;
 
-Uh, this code has no tests.  I'm really sorry.  I'll get around to it.
+__END__
+=pod
+
+=head1 NAME
+
+Test::MinimumVersion - does your code require newer perl than you think?
+
+=head1 VERSION
+
+version 0.101050
+
+=head1 SYNOPSIS
+
+Example F<minimum-perl.t>:
+
+  #!perl
+  use Test::MinimumVersion;
+  all_minimum_version_ok('5.008');
+
+=head1 FUNCTIONS
+
+=head2 minimum_version_ok
+
+  minimum_version_ok($file, $version);
+
+This test passes if the given file does not seem to require any version of perl
+newer than C<$version>, which may be given as a version string or a version
+object.
+
+=head2 all_minimum_version_ok
+
+  all_minimum_version_ok($version, \%arg);
+
+Given either a version string or a L<version> object, this routine produces a
+test plan (if there is no plan) and tests each relevant file with
+C<minimum_version_ok>.
+
+Relevant files are found by L<File::Find::Rule::Perl>.
+
+C<\%arg> is optional.  Valid arguments are:
+
+  paths   - in what paths to look for files; defaults to (t, lib, xt/smoke,
+            and any .pm or .PL files in the current working directory)
+            if it contains files, they will be checked
+  no_plan - do not plan the tests about to be run
+
+=head2 all_minimum_version_from_metayml_ok
+
+  all_minimum_version_from_metayml_ok(\%arg);
+
+This routine checks F<META.yml> for an entry in F<requires> for F<perl>.  If no
+META.yml file or no perl version is found, all tests are skipped.  If a version
+is found, the test proceeds as if C<all_minimum_version_ok> had been called
+with that version.
 
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs at cpan.org> >>
+  Ricardo Signes
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2007, Ricardo SIGNES.
+This software is copyright (c) 2007 by Ricardo Signes.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
